﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Threading;
using System.Diagnostics;
using System.Drawing.Imaging;

namespace WinGridLoadingIndicator
{
    public partial class Form1 : Form
    {
        static Image pindicator = Image.FromFile("..//..//progress.gif");
        DataSet ds;
        BackgroundWorker bw = new BackgroundWorker();
        enum GridState {BeiginUpdate, Updating, EndUpdate };
        public Form1()
        {
            InitializeComponent();
            ultraGrid1.DataSource = GenerateDataSet();
            bw.WorkerReportsProgress = true;
            bw.DoWork += new DoWorkEventHandler(bw_DoWork);
            bw.RunWorkerCompleted += new RunWorkerCompletedEventHandler(bw_RunWorkerCompleted);
            bw.ProgressChanged += new ProgressChangedEventHandler(bw_ProgressChanged);
        }

        void bw_ProgressChanged(object sender, ProgressChangedEventArgs e)
        {
            switch ((GridState)e.UserState)
            {
                case GridState.BeiginUpdate:
                    ultraGrid1.BeginUpdate();
                    break;
                case GridState.Updating:
                    ultraGrid1.DataSource = ds;
                    break;
                case GridState.EndUpdate:
                    ultraGrid1.EndUpdate();
                     
                    break;
            }
        }

        void bw_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
        {

            PictureBox pb = (PictureBox)ultraGrid1.Controls["MyIndicator"];
            this.Controls.Remove(pb);
            if(pb != null)
            pb.Dispose();
            this.Refresh();
        }

        void bw_DoWork(object sender, DoWorkEventArgs e)
        {
            bw.ReportProgress(0, GridState.BeiginUpdate);

            ds = GenerateDataSet();
            bw.ReportProgress(0, GridState.Updating);
            bw.ReportProgress(1, GridState.EndUpdate);
           
        }

        private void ultraButton1_Click(object sender, EventArgs e)
        {
            Bitmap  bmp = new Bitmap( ultraGrid1.Width, ultraGrid1.Height);
            ultraGrid1.DrawToBitmap(bmp, ultraGrid1.ClientRectangle);

            PictureBox pb = new PictureBox();
            pb.Name = "MyIndicator";
            pb.Size = ultraGrid1.Size;
            pb.Location = new Point(0, 0);
            pb.Image = pindicator;
            pb.BackgroundImage = MakeFadeScale(bmp, (Color)ultraColorPicker1.Value);
            pb.BackgroundImageLayout = ImageLayout.Stretch;
            pb.SizeMode = PictureBoxSizeMode.CenterImage;
            
            this.Controls.Add(pb);
            ultraGrid1.Controls.Add(pb);

            this.Refresh();
            bw.RunWorkerAsync();

        }

        public DataSet GenerateDataSet()
        {
            DataTable table0 = new DataTable("Treatment Fluu");
            table0.Columns.Add("ID", typeof(int));
            table0.Columns.Add("Dosage", typeof(int));
            table0.Columns.Add("Drug", typeof(string));
            table0.Columns.Add("Patient", typeof(string));
            table0.Columns.Add("Date", typeof(DateTime));

            for (int i = 0; i < 100000; i++)
            {
             table0.Rows.Add(1, 25, "Indocin", "David", DateTime.Now);
            }
            table0.Rows.Add(1, 25, "Indocin", "David", DateTime.Now);
            table0.Rows.Add(2, 50, "Enebrel", "Sam", DateTime.Now);
            table0.Rows.Add(3, 10, "Hydralazine", "Christoff", DateTime.Now);
            table0.Rows.Add(4, 21, "Combivent", "Janet", DateTime.Now);
            table0.Rows.Add(5, 100, "Dilantin", "Melanie", DateTime.Now);

            DataTable table1 = new DataTable("Patient Inof");
            table1.Columns.Add("ID", typeof(int));
            table1.Columns.Add("TFID", typeof(int));
            table1.Columns.Add("Name", typeof(string));
            table1.Columns.Add("Inspection", typeof(string));
            table1.Columns.Add("Date", typeof(DateTime));

            for (int i = 0; i < 100000; i++)
            {
            table1.Rows.Add(1, 1, "David", "Control", DateTime.Now);
            }
            table1.Rows.Add(1, 1, "David", "Control", DateTime.Now);
            table1.Rows.Add(2, 1, "David", "Patient visitation", DateTime.Now);
            table1.Rows.Add(3, 1, "David", "Patient visitation", DateTime.Now);
            table1.Rows.Add(4, 2, "Sam", "Control", DateTime.Now);
            table1.Rows.Add(5, 3, "Christoff", "Control", DateTime.Now);
            table1.Rows.Add(6, 4, "Janet", "Control", DateTime.Now);
            table1.Rows.Add(7, 4, "Janet", "Patient visitation", DateTime.Now);
            table1.Rows.Add(8, 5, "Melanie", "Control", DateTime.Now);
            table1.Rows.Add(9, 5, "Melanie", "Patient visitation", DateTime.Now);


            DataSet RetDataSet = new DataSet();
            RetDataSet.Tables.Add(table0);
            RetDataSet.Tables.Add(table1);
            //RetDataSet.Relations.Add(RetDataSet.Tables["Treatment Fluu"].Columns["ID"],
            //RetDataSet.Tables["Patient Inof"].Columns["TFID"]);

            return RetDataSet;

        }

        public static ImageAttributes Filter(Color color)
        {
            float r = ((float)color.R) / 255;
            float g =  ((float)color.G) / 255;
            float b =  ((float)color.B) / 255;

            ColorMatrix TempMatrix = new ColorMatrix(new float[][]{
                       new float[] {r, 0, 0, 0, 0},
                       new float[] {0, g, 0, 0, 0},
                       new float[] {0, 0, b, 0, 0},
                       new float[] {0, 0, 0, 1, 0},
                       new float[] {0, 0, 0, 0, 1}
                  });

            ImageAttributes atr = new ImageAttributes();
            atr.SetColorMatrix(TempMatrix);
            return atr;

        }

        public static Bitmap MakeFadeScale(Bitmap original, Color fadeColor)
        {
            //create a blank bitmap the same size as original
            Bitmap newBitmap = new Bitmap(original.Width, original.Height);

            //get a graphics object from the new image
            Graphics g = Graphics.FromImage(newBitmap);

            //create some image attributes
            
            ImageAttributes attributes = Filter(fadeColor);//new ImageAttributes();

            //draw the original image on the new image
            //using the grayscale color matrix
            g.DrawImage(original, new Rectangle(0, 0, original.Width, original.Height),
               0, 0, original.Width, original.Height, GraphicsUnit.Pixel, attributes);

            //dispose the Graphics object
            g.Dispose();
            return newBitmap;
        }

        private void Form1_Load(object sender, EventArgs e)
        {

        }
    }
}
